@@ -84,7 +84,7 @@
 #define KCONFIGQML_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KCONFIGQML_NO_DEPRECATED
-#  define KCONFIGQML_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56c00
+#  define KCONFIGQML_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56d00
 #endif
 #ifdef KCONFIGQML_NO_DEPRECATED_WARNINGS
 #  define KCONFIGQML_DEPRECATED_WARNINGS_SINCE 0
@@ -94,7 +94,7 @@
 #  ifdef KCONFIGQML_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KCONFIGQML_DEPRECATED_WARNINGS_SINCE KCONFIGQML_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KCONFIGQML_DEPRECATED_WARNINGS_SINCE 0x56c00
+#    define KCONFIGQML_DEPRECATED_WARNINGS_SINCE 0x56d00
 #  endif
 #endif
 
